# Python personal set of utils

My set of custom utils that I'm going to use in my projects

## Package name in PyPi is ytils

[ytils](https://pypi.org/project/ytils/#description)


```bash
pip install ytils --upgrade
```
